@@ -2,40 +2,43 @@ package Finance::Bank::JP::MUFG;
 
 use strict;
 use warnings;
-use 5.008001;
-our $VERSION = '0.05';
+use 5.008_001;
+our $VERSION = '0.06';
 
 use WWW::Mechanize;
 use HTML::TreeBuilder::XPath;
 use HTML::Selector::XPath 'selector_to_xpath';
 use List::MoreUtils qw(all any);
 use Cwd qw(getcwd);
-use Carp;
+use Carp        ();
 use Time::Piece ();
 use Encode qw(encode_utf8 from_to);
 use Encode::Alias;
 
-define_alias( shift_jis => 'cp932' );
+use Finance::Bank::JP::MUFG::Account;
+use Finance::Bank::JP::MUFG::Transaction;
+
+define_alias(shift_jis => 'cp932');
 
 my %urls = (
     login => 'https://entry11.bk.mufg.jp/ibg/dfw/APLIN/loginib/login?_TRANID=AA000_001',
 );
 
 my %xpaths = (
-    balance       => '/html/body/div/form[2]/div[3]/div[2]/div[3]/table/tbody/tr',
-    transaction   => '/html/body/div/form[2]/div[3]/div[2]/div[5]/table/tbody/tr',
-    transaction_i => '/html/body/div/form[2]/div[3]/div[2]/div[6]/table/tbody/tr',
-    hidden        => selector_to_xpath('div#container input[type=hidden]'),
-    attention     => selector_to_xpath('div#contents div.serviceContents div.msgArea p.attention'),
-    attention_i   => selector_to_xpath('div#contents div.serviceContents div.infoArea p.attention'),
-    unread_info   => selector_to_xpath('div#contents form[name=informationShousaiActionForm]'),
+    account_balances => '/html/body/div/form[2]/div[3]/div[2]/div[3]/table/tbody/tr',
+    transaction      => '/html/body/div/form[2]/div[3]/div[2]/div[5]/table/tbody/tr',
+    transaction_i    => '/html/body/div/form[2]/div[3]/div[2]/div[6]/table/tbody/tr',
+    hidden           => selector_to_xpath('div#container input[type=hidden]'),
+    attention   => selector_to_xpath('div#contents div.serviceContents div.msgArea p.attention'),
+    attention_i => selector_to_xpath('div#contents div.serviceContents div.infoArea p.attention'),
+    unread_info => selector_to_xpath('div#contents form[name=informationShousaiActionForm]'),
 );
 
 my %transaction_ids = (
     login            => 'AA011_001',
     top              => 'AW001_028',
     logout           => 'AD001_022',
-    balance          => 'AD001_001',
+    account_balances => 'AD001_001',
     search_condition => 'AD001_002',
     transaction      => 'CG016_001',
     download         => 'CG016_002',
@@ -49,25 +52,25 @@ sub _logged_in { shift->{_logged_in} }
 sub xpath_keys          { sort keys %xpaths }
 sub transaction_id_keys { sort keys %transaction_ids }
 
-sub _get_url            { $urls{ $_[0] } }
-sub _get_xpath          { $xpaths{ $_[0] } }
-sub _get_transaction_id { $transaction_ids{ $_[0] } }
+sub _get_url            { $urls{$_[0]} }
+sub _get_xpath          { $xpaths{$_[0]} }
+sub _get_transaction_id { $transaction_ids{$_[0]} }
 
 sub new {
-    my ( $class, %args ) = @_;
+    my ($class, %args) = @_;
 
-    unless ( all { defined $_ } $args{contract_no}, $args{password} ) {
-        croak q{Contract number and password are required.};
+    unless (all { defined $_ } $args{contract_no}, $args{password}) {
+        Carp::croak "Contract number and password are required.";
     }
 
     my $self = bless {%args}, $class;
 
-    $self->{agent} = 'Mac Mozilla' unless _check_agent( $self->{agent} );
+    $self->{agent} = 'Mac Mozilla' unless _check_agent($self->{agent});
     $self->{mech} = WWW::Mechanize->new(
         autocheck   => 1,
         stack_depth => 1,
     );
-    $self->mech()->agent_alias( $self->agent() );
+    $self->mech()->agent_alias($self->agent());
     $self->{_logged_in} = 0;
 
     return $self;
@@ -76,7 +79,7 @@ sub new {
 sub _check_agent {
     my $agent = shift;
     return 0 unless defined $agent;
-    if ( any { $_ eq $agent } WWW::Mechanize::known_agent_aliases() ) {
+    if (any { $_ eq $agent } WWW::Mechanize::known_agent_aliases()) {
         return 1;
     }
     return 0;
@@ -86,25 +89,25 @@ sub login {
     my $self = shift;
     my $mech = $self->mech();
 
-    $mech->get( _get_url('login') );
+    $mech->get(_get_url('login'));
 
     my $top_page = $self->_transition(
         'login',
-        {   KEIYAKU_NO => $self->{contract_no},
+        +{  KEIYAKU_NO => $self->{contract_no},
             PASSWORD   => $self->{password},
         }
     );
 
-    my ( $login_error, $exists_unread_info ) = (
-        _exists_element( $top_page, _get_xpath('attention') ),
-        _exists_element( $top_page, _get_xpath('unread_info') ),
+    my ($login_error, $exists_unread_info) = (
+        _exists_element($top_page, _get_xpath('attention')),
+        _exists_element($top_page, _get_xpath('unread_info')),
     );
 
     if ($login_error) {
-        croak q{Login error.};
+        Carp::croak "Login error.";
     }
     elsif ($exists_unread_info) {
-        croak q{Exist unread information in the top page. Please check it.};
+        Carp::croak "Exist unread information in the top page. Please check it.";
     }
 
     $self->{_logged_in} = 1;
@@ -113,157 +116,158 @@ sub login {
 }
 
 sub _exists_element {
-    my ( $content, $xpath ) = @_;
+    my ($content, $xpath) = @_;
     my $tree = _build_tree($content);
     return $tree->exists($xpath);
 }
 
-sub balances {
+sub accounts {
     my $self = shift;
+    $self->_check_login;
 
-    croak q{Not logged in.} unless $self->_logged_in();
+    my $account_page = $self->_transition('account_balances', +{});
+    my $tree         = _build_tree($account_page);
+    my @names        = Finance::Bank::JP::MUFG::Account->columns;
+    my @rows         = $tree->findnodes(_get_xpath('account_balances'));
+    my @accounts     = ();
 
-    my $balance_page = $self->_transition( 'balance', +{} );
-    my $tree         = _build_tree($balance_page);
-    my @rows         = $tree->findnodes( _get_xpath('balance') );
-    my @keys         = qw(branch account_kind account_no balance withdrawal_limit);
-    my @balances     = ();
-
-    foreach my $row (@rows) {
-        my %balance = ();
+    for my $row (@rows) {
+        my %columns = ();
         my @values  = ();
         my @data    = $row->find_by_tag_name('td');
 
-        foreach my $datum (@data) {
+        for my $datum (@data) {
             my $text = $datum->as_trimmed_text();
             push @values, $text;
         }
 
-        @balance{@keys} = @values;
+        @columns{@names} = @values;
 
-        foreach my $key ( keys %balance ) {
-            if ( $key =~ /balance|withdrawal_limit/ ) {
-                $balance{$key} =~ s/^([\d,]+).*$/$1/;
-                $balance{$key} =~ s/,//g;
-                $balance{$key} =~ s/\*{1,3}/0/;
+        for my $key (keys %columns) {
+            if ($key =~ /balance|withdrawal_limit/) {
+                $columns{$key} =~ s/^([\d,]+).*$/$1/;
+                $columns{$key} =~ s/,//g;
+                $columns{$key} =~ s/\*{1,3}/0/;
             }
-            $balance{$key} = encode_utf8( $balance{$key} );
+            $columns{$key} = encode_utf8($columns{$key});
         }
 
-        push @balances, \%balance;
+        push @accounts, Finance::Bank::JP::MUFG::Account->new(%columns);
     }
 
-    return @balances;
+    return @accounts;
 }
 
 sub transactions {
-    my ( $self, %args ) = @_;
-
-    croak q{Not logged in.} unless $self->_logged_in();
-
-    $self->_transition( 'search_condition', +{} );
+    my ($self, %args) = @_;
+    $self->_check_login;
+    $self->_transition('search_condition', +{});
 
     my $search_condition = _build_condition(%args);
-    my $page = $self->_transition( 'transaction', $search_condition );
+    my $page = $self->_transition('transaction', $search_condition);
 
-    if ( _exists_element( $page, _get_xpath('attention') ) ) {
-        croak q{Invalid search condition.};
+    if (_exists_element($page, _get_xpath('attention'))) {
+        Carp::croak "Invalid search condition.";
     }
 
-    my $exists_info = _exists_element( $page, _get_xpath('attention_i') );
+    my $exists_info = _exists_element($page, _get_xpath('attention_i'));
 
     if ($exists_info) {
-        carp q{Views the details since the beginning of the month of the previous.};
+        Carp::carp "Views the details since the beginning of the month of the previous.";
     }
 
     my $tree         = _build_tree($page);
     my $xpath        = $exists_info ? _get_xpath('transaction_i') : _get_xpath('transaction');
     my @rows         = $tree->findnodes($xpath);
-    my @keys         = qw(date abstract description outlay income balance memo);
+    my @names        = Finance::Bank::JP::MUFG::Transaction->columns;
     my @transactions = ();
 
-    foreach my $row (@rows) {
-        my %transaction = ();
-        my @values      = ();
-        my @data        = $row->find_by_tag_name('td');
+    for my $row (@rows) {
+        my %columns = ();
+        my @values  = ();
+        my @data    = $row->find_by_tag_name('td');
 
-        foreach my $datum (@data) {
+        for my $datum (@data) {
             my $text = $datum->as_trimmed_text();
             push @values, $text;
         }
 
-        @transaction{@keys} = @values;
+        @columns{@names} = @values;
 
-        foreach my $key ( keys %transaction ) {
+        for my $key (keys %columns) {
 
             # no-break space code point.
             my $nbsp = "\xA0";
-            $transaction{$key} =~ s/$nbsp//g;
-
-            if ( $key =~ /date/ ) {
-                my $t = Time::Piece->strptime( $transaction{$key}, '%Y年%m月%d日' );
-                $transaction{$key} = $t;
+            $columns{$key} =~ s/$nbsp//g;
+            if ($key =~ /date/) {
+                my $t = Time::Piece->strptime($columns{$key}, '%Y年%m月%d日');
+                $columns{$key} = $t;
                 next;
             }
-
-            if ( $key =~ /outlay|income|balance/ ) {
-                $transaction{$key} = 0 unless $transaction{$key};
-                $transaction{$key} =~ s/^([\d,]+).*$/$1/;
-                $transaction{$key} =~ s/,//g;
+            if ($key =~ /outlay|income|balance/) {
+                $columns{$key} = 0 unless $columns{$key};
+                $columns{$key} =~ s/^([\d,]+).*$/$1/;
+                $columns{$key} =~ s/,//g;
                 next;
             }
-
-            $transaction{$key} = encode_utf8( $transaction{$key} );
+            $columns{$key} = encode_utf8($columns{$key});
         }
 
-        push @transactions, \%transaction;
+        push @transactions, Finance::Bank::JP::MUFG::Transaction->new(%columns);
     }
 
     return @transactions;
 }
 
 sub download_transactions {
-    my ( $self, %args ) = @_;
+    my ($self, %args) = @_;
+    $self->_check_login;
+
     my $save_dir = delete $args{save_dir} || getcwd;
     my $to_utf8  = delete $args{to_utf8}  || 0;
 
-    if ( not $self->_logged_in() ) {
-        croak q{Not logged in.};
+    if (not -d $save_dir) {
+        Carp::croak "Save dir doesn't exist: $save_dir";
     }
-    elsif ( not -d $save_dir ) {
-        croak q{Save dir doesn't exist.};
-    }
-    elsif ( not $to_utf8 =~ /^[01]$/ ) {
-        carp q{Set the 0 or 1 in the $to_utf8.};
+    elsif (not $to_utf8 =~ /^[01]$/) {
+        Carp::carp "Set the 0 or 1 in the `to_utf8`.";
     }
 
-    $self->_transition( 'search_condition', +{} );
+    $self->_transition('search_condition', +{});
 
     my $search_condition = _build_condition(%args);
-    my $page = $self->_transition( 'download', $search_condition );
+    my $page = $self->_transition('download', $search_condition);
 
-    if ( _exists_element( $page, _get_xpath('attention') ) ) {
-        croak q{Invalid search condition.};
+    if (_exists_element($page, _get_xpath('attention'))) {
+        Carp::croak "Invalid search condition.";
     }
-    elsif ( _exists_element( $page, _get_xpath('attention_i') ) ) {
-        carp q{Views the details since the beginning of the month of the previous.};
+    elsif (_exists_element($page, _get_xpath('attention_i'))) {
+        Carp::carp "Views the details since the beginning of the month of the previous.";
     }
 
-    $self->_transition( 'exec_download', +{} );
-    croak q{Unexpected content type.} if $self->mech()->is_html;
+    $self->_transition('exec_download', +{});
+    if ($self->mech()->is_html) {
+        Carp::croak "Unexpected content type.";
+    }
 
     my $filename = $self->_get_filename_from_response;
-    my $content  = $self->mech()->content;               # Not flagged utf8 content.
+
+    # Not flagged utf8 content.
+    my $content = $self->mech()->content;
     $save_dir .= '/' unless $save_dir =~ m!/$!;
     my $filepath = $save_dir . $filename;
 
-    croak q{Already exists the file.} if -e $filepath;
-
-    if ( $to_utf8 =~ /^[1]$/ ) {
-        from_to( $content, 'cp932', 'utf8' );
+    if (-e $filepath) {
+        Carp::croak "Already exists the file.";
     }
 
-    _save_content( $content, $filepath );                # Back to the html content.
+    if ($to_utf8 =~ /^[1]$/) {
+        from_to($content, 'cp932', 'utf8');
+    }
+
+    _save_content($content, $filepath);
+
+    # Back to the before page.
     $self->mech()->back;
 
     return $filepath;
@@ -272,56 +276,52 @@ sub download_transactions {
 sub _get_filename_from_response {
     my $self     = shift;
     my $response = $self->mech()->response();
-    return $response->filename or croak q{Couldn't get file name.};
+    return $response->filename or Carp::croak "Couldn't get file name.";
 }
 
 sub _build_condition {
-    my %args              = @_;
-    my $default_condition = +{
-        KOUZA_RADIO  => 0,
-        SHURUI_RADIO => 0,
-        KIKAN_RADIO  => 0,
-    };
+    my %args = @_;
 
-    return $default_condition unless %args;
+    unless (%args) {
+        Carp::croak "Not specify search condition.";
+    }
 
-    my $account_no       = _default_value( delete $args{account_no},       1, qr/^[1-9]$/ );
-    my $transaction_kind = _default_value( delete $args{transaction_kind}, 1, qr/^[1-4]$/ );
-    my $period           = _default_value( delete $args{period},           1, qr/^[1-4]$/ );
+    my $account_no       = _default_value(delete $args{account_no},       1, qr/^[1-9]$/);
+    my $transaction_kind = _default_value(delete $args{transaction_kind}, 1, qr/^[1-4]$/);
+    my $period           = _default_value(delete $args{period},           1, qr/^[1-4]$/);
 
     return +{
         KOUZA_RADIO  => _convert_value_to_order($account_no),
         SHURUI_RADIO => _convert_value_to_order($transaction_kind),
         KIKAN_RADIO  => _convert_value_to_order($period),
-    } if ( $period == 1 || $period == 2 );
+    } if ($period == 1 || $period == 2);
 
     my $condition = +{};
 
-    if ( $period == 3 ) {
+    if ($period == 3) {
 
-        unless ( exists $args{date} ) {
-            carp q{If the value of period is 3, date is required. Changes to today.};
+        unless (exists $args{date}) {
+            Carp::carp "If the value of period is 3, `date` is required. Changes to today.";
         }
 
         my $regexp_date = qr!^([\d]{4,4})/(0?[1-9]|1[012])/(0?[1-9]|[12][0-9]|3[01])$!;
-        my $date = _default_value( delete $args{date}, Time::Piece->localtime->ymd('/'),
-            qr!$regexp_date! );
-        my $t = Time::Piece->strptime( $date, '%Y/%m/%d' );
+        my $date = _default_value(delete $args{date}, Time::Piece->localtime->ymd('/'),
+            qr!$regexp_date!);
+        my $t = Time::Piece->strptime($date, '%Y/%m/%d');
 
         $condition = +{
             KOUZA_RADIO    => _convert_value_to_order($account_no),
             SHURUI_RADIO   => _convert_value_to_order($transaction_kind),
             KIKAN_RADIO    => _convert_value_to_order($period),
-            HIZUKESHITEI_Y => _convert_year_to_order( $t->year ),
-            HIZUKESHITEI_M => _convert_value_to_order( $t->mon ),
-            HIZUKESHITEI_D => _convert_value_to_order( $t->mday ),
+            HIZUKESHITEI_Y => _convert_year_to_order($t->year),
+            HIZUKESHITEI_M => _convert_value_to_order($t->mon),
+            HIZUKESHITEI_D => _convert_value_to_order($t->mday),
         };
     }
-    elsif ( $period == 4 ) {
+    elsif ($period == 4) {
 
-        unless ( exists $args{from} ) {
-            carp q{If the value of period is 4, from is required. Changes to default condition.};
-            return $default_condition;
+        unless (exists $args{from}) {
+            Carp::croak "If the value of period is 4, `from` is required.";
         }
 
         my $t           = Time::Piece->localtime;
@@ -329,33 +329,32 @@ sub _build_condition {
         my $to          = delete $args{to} || $t->ymd('/');
         my $regexp_date = qr!^([\d]{4,4})/(0?[1-9]|1[012])/(0?[1-9]|[12][0-9]|3[01])$!;
 
-        if ( !$from =~ /$regexp_date/ || !$to =~ /$regexp_date/ ) {
-            carp q{Not the date formart. Changes to default condition.};
-            return $default_condition;
+        if (!$from =~ /$regexp_date/ || !$to =~ /$regexp_date/) {
+            Carp::croak "Invalid date formart: $from - $to";
         }
 
-        my $t_from = Time::Piece->strptime( $from, '%Y/%m/%d' );
-        my $t_to   = Time::Piece->strptime( $to,   '%Y/%m/%d' );
+        my $t_from = Time::Piece->strptime($from, '%Y/%m/%d');
+        my $t_to   = Time::Piece->strptime($to,   '%Y/%m/%d');
 
-        if ( $t_from > $t_to ) {
-            carp q{Needs to change the from_date before the to_date. Changes to default condition.};
-            return $default_condition;
+        if ($t_from > $t_to) {
+            my ($t_from_ymd, $t_to_ymd) = ($t_from->ymd('/'), $t_to->ymd('/'));
+            Carp::croak "Needs to change the from_date before the to_date: $t_from_ymd > $t_to_ymd";
         }
-        elsif ( $t_to > $t ) {
-            carp q{Can't specify a date in the future. Changes to default condition.};
-            return $default_condition;
+        elsif ($t_to > $t) {
+            my ($t_to_ymd, $t_ymd) = ($t_to->ymd('/'), $t->ymd('/'));
+            Carp::croak "Can't specify a date in the future: $t_to_ymd > $t_ymd";
         }
 
         $condition = +{
             KOUZA_RADIO        => _convert_value_to_order($account_no),
             SHURUI_RADIO       => _convert_value_to_order($transaction_kind),
             KIKAN_RADIO        => _convert_value_to_order($period),
-            KIKANSHITEI_Y_FROM => _convert_year_to_order( $t_from->year ),
-            KIKANSHITEI_M_FROM => _convert_value_to_order( $t_from->mon ),
-            KIKANSHITEI_D_FROM => _convert_value_to_order( $t_from->mday ),
-            KIKANSHITEI_Y_TO   => _convert_year_to_order( $t_to->year ),
-            KIKANSHITEI_M_TO   => _convert_value_to_order( $t_to->mon ),
-            KIKANSHITEI_D_TO   => _convert_value_to_order( $t_to->mday ),
+            KIKANSHITEI_Y_FROM => _convert_year_to_order($t_from->year),
+            KIKANSHITEI_M_FROM => _convert_value_to_order($t_from->mon),
+            KIKANSHITEI_D_FROM => _convert_value_to_order($t_from->mday),
+            KIKANSHITEI_Y_TO   => _convert_year_to_order($t_to->year),
+            KIKANSHITEI_M_TO   => _convert_value_to_order($t_to->mon),
+            KIKANSHITEI_D_TO   => _convert_value_to_order($t_to->mday),
         };
     }
 
@@ -363,12 +362,13 @@ sub _build_condition {
 }
 
 sub _default_value {
-    my ( $value, $default, $regexp ) = @_;
+    my ($value, $default, $regexp) = @_;
     return $default unless defined $value;
-    if ( $value =~ /$regexp/ ) {
+    if ($value =~ /$regexp/) {
         return $value;
     }
-    carp q{Unexpected argment. Changes to default value.};
+    Carp::carp "Unexpected argment: $value";
+    Carp::carp "Changes to default value: $value -> $default";
     return $default;
 }
 
@@ -381,13 +381,10 @@ sub _convert_year_to_order {
         $current_year - 1 => 1,
         $current_year     => 2,
     );
+    my $order = $year_map{_default_value($year, $t->year, qr/^[\d]{4,4}$/)};
 
-    $year = _default_value( $year, $t->year, qr/^[\d]{4,4}$/ );
-
-    my $order = $year_map{$year};
-
-    unless ( defined $order ) {
-        carp q{Unexpected year's value. Changes to current year.};
+    unless (defined $order) {
+        Carp::carp "Unexpected year's value. Changes to current year.";
         $order = 2;
     }
 
@@ -400,35 +397,35 @@ sub _convert_value_to_order {
 }
 
 sub _save_content {
-    my ( $content, $filepath ) = @_;
-
-    open( my $fh, '>', $filepath ) or croak "Unable to create $filepath: $!";
+    my ($content, $filepath) = @_;
+    open(my $fh, '>', $filepath) or Carp::croak "Unable to create $filepath: $!";
     binmode $fh;
-    print {$fh} $content or croak "Unable to write to $filepath: $!";
-    close $fh or croak "Unable to close $filepath: $!";
-
+    print {$fh} $content or Carp::croak "Unable to write to $filepath: $!";
+    close $fh or Carp::croak "Unable to close $filepath: $!";
     return;
 }
 
 sub _transition {
-    my ( $self, $transaction_key, $fields ) = @_;
+    my ($self, $transaction_key, $fields) = @_;
 
     $fields ||= +{};
-    croak q{Trnsaction Key is required.} unless defined $transaction_key;
-    croak q{Trnsaction Key is invalid.}  unless _check_transaction_key($transaction_key);
-    croak q{Not a HASH reference.}       unless ( ref $fields eq 'HASH' );
+    Carp::croak "Trnsaction Key is required." unless defined $transaction_key;
+    Carp::croak "Trnsaction Key is invalid."  unless _check_transaction_key($transaction_key);
+    Carp::croak "Not a HASH reference."       unless (ref $fields eq 'HASH');
 
     my $mech  = $self->mech();
-    my $tree  = _build_tree( $mech->content );
-    my @nodes = $tree->findnodes( _get_xpath('hidden') );
+    my $tree  = _build_tree($mech->content);
+    my @nodes = $tree->findnodes(_get_xpath('hidden'));
 
-    $fields = _create_form_fields( $transaction_key, $fields, \@nodes );
+    $fields = _create_form_fields($transaction_key, $fields, \@nodes);
     $mech->submit_form(
         form_name => 'MainForm',
         fields    => $fields,
     );
 
-    croak q{Login session has expired.} if $mech->content =~ /IW052/;
+    if ($mech->content =~ /IW052/) {
+        Carp::croak "Login session has expired.";
+    }
 
     return $mech->content;
 }
@@ -444,25 +441,29 @@ sub _build_tree {
 sub _check_transaction_key {
     my $transaction_key = shift;
     return 0 unless defined $transaction_key;
-    if ( any { $_ eq $transaction_key } transaction_id_keys() ) {
+    if (any { $_ eq $transaction_key } transaction_id_keys()) {
         return 1;
     }
     return 0;
 }
 
 sub _create_form_fields {
-    my ( $transaction_key, $fields, $hidden_tags ) = @_;
-
+    my ($transaction_key, $fields, $hidden_tags) = @_;
     $fields ||= +{};
-    map { $fields->{ $_->attr('name') } = $_->attr('value') } @{$hidden_tags};
+    map { $fields->{$_->attr('name')} = $_->attr('value') } @{$hidden_tags};
     $fields->{_TRANID} = _get_transaction_id($transaction_key);
-
     return $fields;
 }
 
+sub _check_login {
+    my $self = shift;
+    Carp::croak "Not logged in." unless $self->_logged_in();
+    return 1;
+}
+
 sub logout {
     my $self = shift;
-    $self->_transition( 'logout', +{} );
+    $self->_transition('logout', +{});
     $self->{_logged_in} = 0;
     return;
 }
@@ -472,55 +473,58 @@ __END__
 
 =head1 NAME
 
-Finance::Bank::JP::MUFG - Checks balances and transactions of MUFG-DIRECT account.
+Finance::Bank::JP::MUFG - Checks account balances and transactions of MUFG-DIRECT account.
 
 =head1 SYNOPSIS
 
   use Finance::Bank::JP::MUFG;
-  use feature qw(say);
 
   my $mufg = Finance::Bank::JP::MUFG->new(
-      contract_no => '12345678',
-      password    => 'direct_password',
-      agent       => 'Windows Mozilla',
-  )->login();
+      contract_no => 'your_contract_no',
+      password    => 'your_direct_password',
+  )->login;
 
-  my @balances = $mufg->balances();
+  my @accounts = $mufg->accounts;
 
-  say $balances[0]->{branch};
-  say $balances[0]->{account_kind};
-  say $balances[0]->{account_no};
-  say $balances[0]->{balance};
-  say $balances[0]->{withdrawal_limit};
+  for my $account (@accounts) {
+      printf "%-s  %-s  %-7s %9syen %9syen\n",
+          $account->branch,
+          $account->account_kind,
+          $account->account_no,
+          commify($account->balance),
+          commify($account->withdrawal_limit);
+  }
 
   my @transactions = $mufg->transactions(
       account_no       => 1,
       transaction_kind => 1,
-      period           => 3,
-      date             => '2012/6/22',
+      period           => 1,
   );
 
-  say $transactions[0]->{date}->ymd('/');
-  say $transactions[0]->{abstract};
-  say $transactions[0]->{description};
-  say $transactions[0]->{outlay};
-  say $transactions[0]->{income};
-  say $transactions[0]->{balance};
-  say $transactions[0]->{memo};
+  for my $transaction (@transactions) {
+      printf "%-s  %-s  %-s  %syen  %syen  %syen  %-s\n",
+          $transaction->date->ymd('/'),
+          $transaction->abstract,
+          $transaction->description,
+          commify($transaction->outlay),
+          commify($transaction->income),
+          commify($transaction->balance),
+          $transaction->memo;
+  }
 
   my $csv_path = $mufg->download_transactions(
       account_no       => 1,
       transaction_kind => 1,
       period           => 4,
-      from             => '2012/6/1',
-      to               => '2012/7/10',
+      from             => '2012/9/1',
+      to               => '2012/10/12',
       save_dir         => '/tmp',
       to_utf8          => 0,
   );
 
   say $csv_path;
 
-  $mufg->logout();
+  $mufg->logout;
 
 =head1 DESCRIPTION
 
@@ -538,8 +542,8 @@ Creates and returns a new Finance::Bank::JP::MUFG object.
 
 This constructor has to pass two parameters of the Contract Number and Password.
 
-  contract_no => '12345678',
-  password    => 'direct_password',
+  contract_no => 'your_contract_no',
+  password    => 'your_direct_password',
 
 You can also specify the user agent.
 
@@ -570,11 +574,11 @@ The list of valid aliases is:
 Runs login process and returns a self object.
 Be sure to call after object creation.
 
-=head2 $mufg->balances()
+=head2 $mufg->accounts()
 
 Returns an array of all the account balances.
-This array stores hash references of each account,
-and you can access with the following keys.
+This array stores L<Finance::Bank::JP::MUFG::Account> objects,
+and you can access with the following accessors.
 
 =over 5
 
@@ -639,12 +643,12 @@ Default value is today and which is optional.
 =back
 
 Returns an array of transactions.
-This array stores hash references of each transaction,
-and you can access with the following keys.
+This array stores L<Finance::Bank::JP::MUFG::Transaction> objects,
+and you can access with the following accessors.
 
 =over 7
 
-=item * date L<Time::Piece>
+=item * L<date|Time::Piece>
 
 =item * abstract
 
@@ -730,7 +734,7 @@ Repository: https://github.com/perforb/p5-Finance-Bank-JP-MUFG
 
 =head1 SEE ALSO
 
-MUFG-DIRECT http://direct.bk.mufg.jp/
+L<MUFG-DIRECT|http://direct.bk.mufg.jp/>
 
 L<WWW::Mechanize>
 
@@ -738,6 +742,10 @@ L<HTML::TreeBuilder::XPath>
 
 L<HTML::Selector::XPath>
 
+L<Finance::Bank::JP::MUFG::Account>
+
+L<Finance::Bank::JP::MUFG::Transaction>
+
 =head1 LICENSE
 
 This library is free software; you can redistribute it and/or modify
